InvoiceResult class

Result model for invoice calculation.

Constructors

InvoiceResult({required double subtotal, required double discount, required double tax, required double total})
const

Properties

discount double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtotal double
final
tax double
final
total double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited