HsnValidator class

Validates HSN/SAC code format.

Constructors

HsnValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValid(String code) bool
Generic validation for either HSN or SAC.
isValidHSN(String hsn) bool
Returns true if HSN code (Goods) is valid.
isValidSAC(String sac) bool
Returns true if SAC code (Services) is valid.